/* Helper functions for directives */

function numberWithCommas(x) {
    return x.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ",");
}

/* Directives */

angular.module('appDirectives', [])

.directive('ngVisible',function () {
    return function(scope, element, attrs) {
        if (attrs.ngVisible === "true") {
          element.css({'visibility': 'visible'});
        } else {
          element.css({'visibility': 'hidden'});
        }
    };
})

.directive('ngPlaceBadge',function () {
    return function(scope, element, attrs) {
        var url = "";
        if (attrs.ngPlaceBadge === "") {
          var base = 'img/hex/plain';
          var hexes = [
            base+'/blue.png',
            base+'/goldenrod.png',
            base+'/paleOrange.png',
            base+'/sage.png',
            base+'/rust.png'
          ];
          url = hexes[Math.floor(Math.random() * hexes.length)];
        }  else {
          url = 'img/hex/badges/'+attrs.ngPlaceBadge+'.png'
        }
        element.attr({'src': url});
    };
})

/* directives for a mode indicator element */

.directive('ngIndicatorPosition',function () {
    return function(scope, element, attrs) {
      if (attrs.ngIndicatorPosition === "left") {
        element.css({'left': '100px'});
      } else if (attrs.ngIndicatorPosition === "middle") {
        element.css({'left': '45%'});        
      } else {
        element.css({'right': '100px'});
      }
    };
})

.directive('ngIndicatorPositionRandom',function () {
    return function(scope, element, attrs) {
      var leftExtent = 30;
      var rightExtent = 60;
      var alpha = Math.random();
      var pos = (1- alpha) * leftExtent + alpha * rightExtent;
      element.css({'left': pos+'%'});
    };
})

.directive('ngIndicatorPositionRace',function () {
    return function(scope, element, attrs) {
      var modePercentage = attrs.ngIndicatorPositionRace;
      var leftExtent = 30;
      var rightExtent = 60;
      var alpha = Math.random();
      var pos = (1- alpha) * leftExtent + alpha * rightExtent;
      element.css({'left': pos+'%'});
    };
})

.directive('ngModeIcon',function () {
    return function(scope, element, attrs) {
      var modeId = attrs.ngModeIcon;
      if (modeId !== null && typeof modeId !== 'undefined' && modeId !== '') {
        var modeImg = scope.modes[modeId - 1].img;
        element.css({'background-image': 'url('+modeImg+')'});
        element.css({'background-size': 'auto 78%'});
        element.css({'background-position': 'center'});
        element.css({'background-repeat': 'no-repeat'});
      }
    };
})

.directive('ngSystemModeIcon',function () {
    return function(scope, element, attrs) {
      var modeImg = scope.systemMode.img;
      element.css({'background-image': 'url('+modeImg+')'});
      element.css({'background-size': 'auto 78%'});
      element.css({'background-position': 'center'});
      element.css({'background-repeat': 'no-repeat'});
    };
})

.directive('ngNumberWithCommas',function () {
    return function(scope, element, attrs) {
      var text = element.text();
      element.text(numberWithCommas(text));
    };
})

.directive('ngSectionBanner',function () {
    return function(scope, element, attrs) {
      var sectionId = attrs.ngSectionBanner;
      if (sectionId === "1") {
        element.addClass('pale-orange');
      } else if (sectionId === "2") {
        element.addClass('rust');
      } else if (sectionId === "3") {
        element.addClass('goldenrod');
      } else if (sectionId === "4") {
        element.addClass('sage');
      } else if (sectionId === "5") {
        element.addClass('blue');
      } 
    };
});

