// A helper that checks to see if it is safe to do an apply
function safeApply(scope, fn) {
    (scope.$$phase) ? fn() : scope.$apply(fn);
}

function foursquareQueryURL(loc) {
  var fsBaseURL = 'https://api.foursquare.com/v2';
  var fsAPIVersion = '20130425';
  var fsClientID = window.keys.fsClientId;
  var fsClientSecret = window.keys.fsClientSecret;
  var fsLocation = "intent=global";
  if (loc !== null) {
    fsLocation = "ll=" + loc.lat + "," + loc.lon
  }
  var fsQueryURL = fsBaseURL+'/venues/search?query=%QUERY&limit=20' + '&' + fsLocation +
                   '&client_id='+fsClientID+'&client_secret='+fsClientSecret+'&v='+fsAPIVersion;
  return fsQueryURL;
}

function bingQueryURL(loc) {
  var bingKey = window.keys.bingKey;
  var query = 'https://dev.virtualearth.net/REST/v1/Locations?q=%QUERY&o=json&key=' + bingKey + '&jsonp=?'
  if (loc !== null) {
    query += '&userLocation=' + loc.lat + "," + loc.lon;
  }
  return query;
}

function prepPlaceDataForPost(place) {
    if (place.source === 'venue') {
      return prepVenueForPost(place);
    }
    else if (place.source === 'address') {
      return prepAddressForPost(place);
    }
    else {
      return null;
    }
}

function prepPlaceDataForPost(place) {
    if (place.source === 'venue') {
      return prepVenueForPost(place);
    }
    else if (place.source === 'address') {
      return prepAddressForPost(place);
    }
    else {
      return null;
    }
}

function prepVenueForPost(venue) {
  /*
  {"id":"513e2652e4b0d54ae5b8d310","name":"FUSE Labs","contact":{},"location":{"lat":47.64049921290027,"lng":-122.14128775512013,"distance":14828,"cc":"US","city":"Redmond","state":"WA","country":"United States","formattedAddress":["Redmond, WA","United States"]},"categories":[],"verified":false,"stats":{"checkinsCount":107,"usersCount":17,"tipCount":1},"specials":{"count":0,"items":[]},"hereNow":{"count":0,"summary":"0 people here","groups":[]},"referralId":"v-1404757590","source":"venue"}
  */

  var cat = null;
  var catId = null;
  var catNP = null;
  if (venue.categories.length > 0) {
    cat = venue.categories[0].name;
    catId = venue.categories[0].id;

    /*
     * currently pulling the root category from the icon url
     * this is not always accurate (e.g. tech startup uses a shop icon)
     * in the future we should build a lookup table
     */
    var iconPrefix = venue.categories[0].icon.prefix;
    if (iconPrefix.search("arts_entertainment") >= 0) {
      catNP = "artsEntertainment";
    } else if (iconPrefix.search("education") >= 0) {
      catNP = "collegeUniversity";
    } else if (iconPrefix.search("food") >= 0) {
      catNP = "food";
    } else if (iconPrefix.search("shop") >= 0) {
      catNP = "shopService";
    } else if (iconPrefix.search("nightlife") >= 0) {
      catNP = "nightlifeSpot";
    } else if (iconPrefix.search("travel") >= 0) {
      catNP = "travelTransport";
    } else if (iconPrefix.search("parks_outdoors") >= 0) {
      catNP = "outdoorsRecreation";
    } else if (iconPrefix.search("building/apartment") >= 0 ||
               iconPrefix.search("building/home") >= 0 ||
               iconPrefix.search("building/hous") >= 0) {
      catNP = "residence";
    } else if (iconPrefix.search("building") >= 0) {
      catNP = "professionalOtherPlaces";
    }
  }

  var dat = {
    name: venue.name,
    venue_id: venue.id,
    category_fs: cat,
    category_fs_id: catId,
    category_np: catNP,
    location_lat: venue.location.lat,
    location_lon: venue.location.lng,
    location_address: venue.location.formattedAddress.join(", ")
  }
  return dat;
}

function prepAddressForPost(address) {
  /*
  {"__type":"Location:http://schemas.microsoft.com/search/local/ws/rest/v1","bbox":[47.253395080566406,-123.16571807861328,47.94615936279297,-121.5034408569336],"name":"Seattle, WA","point":{"type":"Point","coordinates":[47.60356903076172,-122.32945251464844]},"address":{"adminDistrict":"WA","adminDistrict2":"King Co.","countryRegion":"United States","formattedAddress":"Seattle, WA","locality":"Seattle"},"confidence":"High","entityType":"PopulatedPlace","geocodePoints":[{"type":"Point","coordinates":[47.60356903076172,-122.32945251464844],"calculationMethod":"Rooftop","usageTypes":["Display"]}],"matchCodes":["Good"],"source":"address"}
  */
  var dat = {
    name: address.name,
    venue_id: null,
    category_fs: null,
    category_fs_id: null,
    category_np: null,
    location_lat: address.point.coordinates[0],
    location_lon: address.point.coordinates[1],
    location_address: address.address.formattedAddress
  };
  return dat;
}

// This should still be the initial location when init root variables
function getDefaultLocation() {
  //navigator.geolocation.getCurrentPosition(onSuccess, onError);
  return {"lat": 47.610521, "lon": -122.333867};
}

function onError(error) {
  alert('code: ' + error.code + '\n' +
    'message: ' + error.message + '\n');
}

function onHttpError(error) {
	if (error.status == "")
  		alert("Ouch, we’re having some technical difficulties: no connection");
	else
		alert("Ouch, we’re having some technical difficulties: HTTP error " + error.status);
}
